@@ -197,24 +197,6 @@ class SignedFunction(_function_base.Function):
         callargs[kwargs_name] = k.to_variable(node)
     return callargs
 
-  def _match_view(self, node, args, view, alias_map=None):
-    arg_dict = {}
-    formal_args = []
-    for name, arg, formal in self.signature.iter_args(args):
-      arg_dict[name] = view[arg]
-      if formal is not None:
-        if name in (self.signature.varargs_name, self.signature.kwargs_name):
-          # The annotation is Tuple or Dict, but the passed arg only has to be
-          # Iterable or Mapping.
-          formal = self.ctx.convert.widen_type(formal)
-        formal_args.append((name, formal))
-    subst, bad_arg = self.ctx.matcher(node).compute_subst(
-        formal_args, arg_dict, view, alias_map)
-    if subst is None:
-      raise function.WrongArgTypes(
-          self.signature, args, self.ctx, bad_param=bad_arg)
-    return subst
-
   def _match_args_sequentially(self, node, args, alias_map, match_all_views):
     args_to_match = []
     for name, arg, formal in self.signature.iter_args(args):
@@ -347,7 +329,7 @@ class SimpleFunction(SignedFunction):
     if self.name == "__new__":
       self_arg = ret
     else:
-      self_arg = self.signature.get_first_arg(callargs)
+      self_arg = self.signature.get_self_arg(callargs)
     mutations = self._mutations_generator(node, self_arg, substs)
     node = abstract_utils.apply_mutations(node, mutations)
     return node, ret
@@ -633,6 +615,49 @@ class InterpreterFunction(SignedFunction):
       callkey = len(self._call_cache)
     return callkey
 
+  def _handle_typeguard(self, node, ret, first_arg):
+    frame = self.ctx.vm.frame
+    if not hasattr(frame, "f_locals"):
+      return None  # no need to apply TypeGuard if we're in a dummy frame
+    if ret.full_name != "typing.TypeGuard":
+      return None
+    # TODO(b/217789670): Log an error if the TypeGuard isn't parameterized.
+    new_type = ret.get_formal_type_parameter(abstract_utils.T)
+
+    # Get the local/global variable that first_arg comes from, and add new
+    # bindings for the TypeGuard type.
+    # TODO(b/217789670): This step isn't needed if the TypeGuard type is already
+    # present in first_arg.
+    target_name = self.ctx.vm.get_var_name(first_arg)
+    if not target_name:
+      # TODO(b/217789670): Log a not-supported-yet error if the variable does
+      # not have a name.
+      return None
+    if target_name in frame.f_locals.members:
+      store = frame.f_locals
+    else:
+      store = frame.f_globals
+    target = store.members[target_name]
+    # Forward all the target's bindings to the current node, so we don't have
+    # visibility problems later.
+    target.PasteVariable(target, node)
+    old_data = set(target.data)
+    # TODO(b/217789670): Should we use init_annotation? What should be passed in
+    # for 'name' if we do?
+    _, new_instance = self.ctx.vm.init_class(node, new_type)
+    for b in new_instance.bindings:
+      if b.data not in target.data:
+        target.PasteBinding(b, node)
+
+    # Create a boolean return variable with True bindings for values that
+    # originate from the TypeGuard type and False for the rest.
+    typeguard_return = self.ctx.program.NewVariable()
+    for b in target.bindings:
+      boolvals = {b.data not in old_data} | {b.data in new_instance.data}
+      for v in boolvals:
+        typeguard_return.AddBinding(self.ctx.convert.bool_values[v], {b}, node)
+    return typeguard_return
+
   def call(self, node, func, args, alias_map=None, new_locals=False,
            frame_substs=()):
     if self.is_overload:
@@ -656,7 +681,7 @@ class InterpreterFunction(SignedFunction):
       # We've matched an overload; remap the callargs using the implementation
       # so that optional parameters, etc, are correctly defined.
       callargs = self._map_args(node, args)
-    first_arg = sig.get_first_arg(callargs)
+    self_arg = sig.get_self_arg(callargs)
     annotation_substs = substs
     # Adds type parameter substitutions from all containing classes. Note that
     # lower frames (ones closer to the end of self.ctx.vm.frames) take
@@ -668,10 +693,19 @@ class InterpreterFunction(SignedFunction):
     # type-checking down the road.
     annotations = self.ctx.annotation_utils.sub_annotations(
         node, sig.annotations, annotation_substs, instantiate_unbound=False)
+
+    # TODO(b/217789670): Log an error if the TypeGuard function doesn't accept
+    # enough arguments.
+    first_arg = sig.get_first_arg(callargs)
+    if first_arg and sig.has_return_annotation:
+      typeguard_return = self._handle_typeguard(
+          node, annotations["return"], first_arg)
+    else:
+      typeguard_return = None
     if sig.has_param_annotations:
-      if first_arg and sig.param_names[0] == "self":
+      if self_arg:
         try:
-          maybe_container = abstract_utils.get_atomic_value(first_arg)
+          maybe_container = abstract_utils.get_atomic_value(self_arg)
         except abstract_utils.ConversionError:
           container = None
         else:
@@ -695,7 +729,7 @@ class InterpreterFunction(SignedFunction):
               annotations[name],
               container=container,
               extra_key=extra_key)
-    mutations = self._mutations_generator(node, first_arg, substs)
+    mutations = self._mutations_generator(node, self_arg, substs)
     node = abstract_utils.apply_mutations(node, mutations)
     if substs:
       frame_substs = tuple(itertools.chain(frame_substs, substs))
@@ -709,7 +743,7 @@ class InterpreterFunction(SignedFunction):
           self.closure,
           new_locals=new_locals,
           func=func,
-          first_arg=first_arg,
+          first_arg=self_arg or first_arg,
           substs=frame_substs)
     except self.ctx.vm.VirtualMachineRecursionError:
       # If we've encountered recursion in a constructor, then we have another
@@ -721,8 +755,8 @@ class InterpreterFunction(SignedFunction):
       # as incomplete.
       self._set_callself_maybe_missing_members()
       return node, self.ctx.new_unsolvable(node)
-    caller_is_abstract = _check_classes(first_arg, lambda cls: cls.is_abstract)
-    caller_is_protocol = _check_classes(first_arg, lambda cls: cls.is_protocol)
+    caller_is_abstract = _check_classes(self_arg, lambda cls: cls.is_abstract)
+    caller_is_protocol = _check_classes(self_arg, lambda cls: cls.is_protocol)
     # We should avoid checking the return value against any return annotation
     # when we are analyzing an attribute of a protocol or an abstract class's
     # abstract method.
@@ -749,7 +783,7 @@ class InterpreterFunction(SignedFunction):
             "remaining_depth = %d, old_remaining_depth = %d", self.name,
             self.ctx.vm.remaining_depth(), old_remaining_depth)
       else:
-        ret = old_ret.AssignToNewVariable(node)
+        ret = typeguard_return or old_ret.AssignToNewVariable(node)
         if self._store_call_records:
           # Even if the call is cached, we might not have been recording it.
           self._call_records.append((callargs, ret, node))
@@ -796,7 +830,7 @@ class InterpreterFunction(SignedFunction):
     if self._store_call_records or self.ctx.store_all_calls:
       self._call_records.append((callargs, ret, node_after_call))
     self.last_frame = frame
-    return node_after_call, ret
+    return node_after_call, typeguard_return or ret
 
   def get_call_combinations(self, node):
     """Get this function's call records."""
