@@ -49,27 +49,35 @@ def pytd_callable(
     parameters: _ParametersType
 ) -> pytd.Type:
   """Create a pytd.CallableType."""
-  if isinstance(parameters[0], list):
-    if len(parameters) > 2:
-      raise TypeError(
-          f"Expected 2 parameters to Callable, got {len(parameters)}")
-    if len(parameters) == 1:
-      # We're usually happy to treat omitted parameters as "Any", but we
-      # need a return type for CallableType, or we wouldn't know whether the
-      # last parameter is an argument or return type.
-      parameters += (pytd.AnythingType(),)
-    if not parameters[0] or parameters[0] == [pytd.NothingType()]:
+  assert parameters
+  if len(parameters) > 2:
+    raise TypeError(
+        f"Expected 2 parameters to Callable, got {len(parameters)}")
+  if len(parameters) == 1:
+    # TODO(mdemello): We should reject this as a type error!
+    # We're usually happy to treat omitted parameters as "Any", but we
+    # need a return type for CallableType, or we wouldn't know whether the
+    # last parameter is an argument or return type.
+    parameters += (pytd.AnythingType(),)
+  args, ret = parameters
+  if isinstance(args, list):
+    if not args or args == [pytd.NothingType()]:
       # Callable[[], ret] -> pytd.CallableType(ret)
-      parameters = parameters[1:]
+      parameters = (ret,)
     else:
+      if any(x.__class__.__name__ == "Ellipsis" for x in args):
+        # TODO(mdemello): Check in pyi/ instead to avoid leaking the type.
+        if is_any(ret):
+          ret = "Any"
+        msg = f"Invalid Callable args, did you mean Callable[..., {ret}]?"
+        raise TypeError(msg)
       # Callable[[x, ...], ret] -> pytd.CallableType(x, ..., ret)
-      parameters = tuple(parameters[0]) + parameters[1:]
+      parameters = tuple(args) + (ret,)
     return pytd.CallableType(base_type=base_type, parameters=parameters)
   else:
     # Fall back to a generic Callable if first param is Any
-    assert parameters
-    if not is_any(parameters[0]):
+    if not is_any(args):
       msg = ("First argument to Callable must be a list of argument types "
-             "(got %r)" % parameters[0])
+             "(got %r)" % args)
       raise TypeError(msg)
     return pytd.GenericType(base_type=base_type, parameters=parameters)
