@@ -3,9 +3,9 @@
 import sys
 import textwrap
 
-from pytype import file_utils
 from pytype.platform_utils import path_utils
 from pytype.pytd import main as pytd_tool
+from pytype.tests import test_utils
 
 import unittest
 
@@ -48,14 +48,14 @@ class TestPytdTool(unittest.TestCase):
       pytd_tool.main()
 
   def test_parse_error(self):
-    with file_utils.Tempdir() as d:
+    with test_utils.Tempdir() as d:
       inpath = d.create_file("in.pytd", "def f(x): str")  # malformed pytd
       sys.argv = ["main.py", inpath]
       with self.assertRaises(SystemExit):
         pytd_tool.main()
 
   def test_no_output(self):
-    with file_utils.Tempdir() as d:
+    with test_utils.Tempdir() as d:
       inpath = d.create_file("in.pytd", "def f(x) -> str: ...")
       # Not specifying an output is fine; the tool simply checks that the input
       # file is parseable.
@@ -63,7 +63,7 @@ class TestPytdTool(unittest.TestCase):
       pytd_tool.main()
 
   def test_output(self):
-    with file_utils.Tempdir() as d:
+    with test_utils.Tempdir() as d:
       src = textwrap.dedent("""
         from typing import overload
 
